@@ -21,7 +21,7 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include "../../libinput/device.h"
 #include "../../libinput/events.h"
 
-#include <QtTest/QtTest>
+#include <QtTest>
 
 #include <memory>
 
