@@ -72,12 +72,12 @@ class KWIN_EXPORT EffectsHandlerImpl : public EffectsHandler
     Q_PROPERTY(QStringList listOfEffects READ listOfEffects)
 public:
     EffectsHandlerImpl(Compositor *compositor, Scene *scene);
-    virtual ~EffectsHandlerImpl();
+    ~EffectsHandlerImpl() override;
     void prePaintScreen(ScreenPrePaintData& data, int time) override;
     void paintScreen(int mask, QRegion region, ScreenPaintData& data) override;
     /**
      * Special hook to perform a paintScreen but just with the windows on @p desktop.
-     **/
+     */
     void paintDesktop(int desktop, int mask, QRegion region, ScreenPaintData& data);
     void postPaintScreen() override;
     void prePaintWindow(EffectWindow* w, WindowPrePaintData& data, int time) override;
@@ -219,13 +219,13 @@ public:
 
     /**
      * @returns Whether we are currently in a desktop rendering process triggered by paintDesktop hook
-     **/
+     */
     bool isDesktopRendering() const {
         return m_desktopRendering;
     }
     /**
      * @returns the desktop currently being rendered in the paintDesktop hook.
-     **/
+     */
     int currentRenderedDesktop() const {
         return m_currentRenderedDesktop;
     }
@@ -252,9 +252,9 @@ public:
         return m_scene;
     }
 
-    bool touchDown(quint32 id, const QPointF &pos, quint32 time);
-    bool touchMotion(quint32 id, const QPointF &pos, quint32 time);
-    bool touchUp(quint32 id, quint32 time);
+    bool touchDown(qint32 id, const QPointF &pos, quint32 time);
+    bool touchMotion(qint32 id, const QPointF &pos, quint32 time);
+    bool touchUp(qint32 id, quint32 time);
 
     void highlightWindows(const QVector<EffectWindow *> &windows);
 
@@ -262,7 +262,7 @@ public:
         return registered_atoms.contains(atom);
     }
 
-    void windowToDesktops(EffectWindow *w, const QVector<uint> &desktops);
+    void windowToDesktops(EffectWindow *w, const QVector<uint> &desktops) override;
 
     /**
      * Finds an effect with the given name.
@@ -270,7 +270,7 @@ public:
      * @param name The name of the effect.
      * @returns The effect with the given name @p name, or nullptr if there
      *     is no such effect loaded.
-     **/
+     */
     Effect *findEffect(const QString &name) const;
 
 public Q_SLOTS:
@@ -311,26 +311,26 @@ protected:
 
     /**
      * Default implementation does nothing and returns @c true.
-     **/
+     */
     virtual bool doGrabKeyboard();
     /**
      * Default implementation does nothing.
-     **/
+     */
     virtual void doUngrabKeyboard();
 
     /**
      * Default implementation sets Effects override cursor on the PointerInputRedirection.
-     **/
+     */
     virtual void doStartMouseInterception(Qt::CursorShape shape);
 
     /**
      * Default implementation removes the Effects override cursor on the PointerInputRedirection.
-     **/
+     */
     virtual void doStopMouseInterception();
 
     /**
      * Default implementation does nothing
-     **/
+     */
     virtual void doCheckInputWindowStacking();
 
     Effect* keyboard_grab_effect;
@@ -490,11 +490,11 @@ public:
 
     void elevate(bool elevate);
 
-    void setData(int role, const QVariant &data);
-    QVariant data(int role) const;
+    void setData(int role, const QVariant &data) override;
+    QVariant data(int role) const override;
 
     void registerThumbnail(AbstractThumbnailItem *item);
-    QHash<WindowThumbnailItem*, QWeakPointer<EffectWindowImpl> > const &thumbnails() const {
+    QHash<WindowThumbnailItem*, QPointer<EffectWindowImpl> > const &thumbnails() const {
         return m_thumbnails;
     }
     QList<DesktopThumbnailItem*> const &desktopThumbnails() const {
@@ -510,7 +510,7 @@ private:
     Toplevel* toplevel;
     Scene::Window* sw; // This one is used only during paint pass.
     QHash<int, QVariant> dataMap;
-    QHash<WindowThumbnailItem*, QWeakPointer<EffectWindowImpl> > m_thumbnails;
+    QHash<WindowThumbnailItem*, QPointer<EffectWindowImpl> > m_thumbnails;
     QList<DesktopThumbnailItem*> m_desktopThumbnails;
     bool managed = false;
     bool waylandClient;
@@ -534,7 +534,7 @@ class KWIN_EXPORT EffectFrameImpl
 public:
     explicit EffectFrameImpl(EffectFrameStyle style, bool staticSize = true, QPoint position = QPoint(-1, -1),
                              Qt::Alignment alignment = Qt::AlignCenter);
-    virtual ~EffectFrameImpl();
+    ~EffectFrameImpl() override;
 
     void free() override;
     void render(QRegion region = infiniteRegion(), double opacity = 1.0, double frameOpacity = 1.0) override;
@@ -576,7 +576,7 @@ public:
     }
     /**
      * The foreground text color as specified by the default Plasma theme.
-     **/
+     */
     QColor styledTextColor();
 
 private Q_SLOTS:
