@@ -41,7 +41,7 @@ namespace Xcb
  *
  * This class is intended as a small abstraction to support multiple compositing backends in the
  * SceneXRender.
- **/
+ */
 class XRenderBackend
 {
 public:
@@ -56,14 +56,14 @@ public:
      * It's the task of the caller to check whether it is @c null.
      *
      * @return :OverlayWindow*
-     **/
+     */
     virtual OverlayWindow *overlayWindow();
     virtual bool usesOverlayWindow() const = 0;
     /**
      * @brief Shows the Overlay Window
      *
      * Default implementation does nothing.
-     **/
+     */
     virtual void showOverlay();
     /**
      * @brief React on screen geometry changes.
@@ -71,7 +71,7 @@ public:
      * Default implementation does nothing. Override if specific functionality is required.
      *
      * @param size The new screen size
-     **/
+     */
     virtual void screenGeometryChanged(const QSize &size);
     /**
      * @brief The compositing buffer hold by this backend.
@@ -79,7 +79,7 @@ public:
      * The Scene composites the new frame into this buffer.
      *
      * @return xcb_render_picture_t
-     **/
+     */
     xcb_render_picture_t buffer() const {
         return m_buffer;
     }
@@ -90,7 +90,7 @@ public:
      * returns @c true, the SceneXRender should not try to start the rendering.
      *
      * @return bool @c true if the creation of the Backend failed, @c false otherwise.
-     **/
+     */
     bool isFailed() const {
         return m_failed;
     }
@@ -102,7 +102,7 @@ protected:
      *
      * @param buffer The buffer to use for compositing
      * @return void
-     **/
+     */
     void setBuffer(xcb_render_picture_t buffer);
     /**
      * @brief Sets the backend initialization to failed.
@@ -111,7 +111,7 @@ protected:
      * The given @p reason is logged as a warning.
      *
      * @param reason The reason why the initialization failed.
-     **/
+     */
     void setFailed(const QString &reason);
 
 private:
@@ -123,18 +123,18 @@ private:
 
 /**
  * @brief XRenderBackend using an X11 Overlay Window as compositing target.
- **/
+ */
 class X11XRenderBackend : public XRenderBackend
 {
 public:
     X11XRenderBackend();
-    ~X11XRenderBackend();
+    ~X11XRenderBackend() override;
 
-    virtual void present(int mask, const QRegion &damage);
-    virtual OverlayWindow* overlayWindow();
-    virtual void showOverlay();
-    virtual void screenGeometryChanged(const QSize &size);
-    virtual bool usesOverlayWindow() const;
+    void present(int mask, const QRegion &damage) override;
+    OverlayWindow* overlayWindow() override;
+    void showOverlay() override;
+    void screenGeometryChanged(const QSize &size) override;
+    bool usesOverlayWindow() const override;
 private:
     void init(bool createOverlay);
     void createBuffer();
@@ -149,23 +149,23 @@ class SceneXrender
     Q_OBJECT
 public:
     class EffectFrame;
-    virtual ~SceneXrender();
-    virtual bool initFailed() const;
-    virtual CompositingType compositingType() const {
+    ~SceneXrender() override;
+    bool initFailed() const override;
+    CompositingType compositingType() const override {
         return XRenderCompositing;
     }
-    virtual qint64 paint(QRegion damage, ToplevelList windows);
-    virtual Scene::EffectFrame *createEffectFrame(EffectFrameImpl *frame);
-    virtual Shadow *createShadow(Toplevel *toplevel);
-    virtual void screenGeometryChanged(const QSize &size);
+    qint64 paint(QRegion damage, ToplevelList windows) override;
+    Scene::EffectFrame *createEffectFrame(EffectFrameImpl *frame) override;
+    Shadow *createShadow(Toplevel *toplevel) override;
+    void screenGeometryChanged(const QSize &size) override;
     xcb_render_picture_t xrenderBufferPicture() const override;
-    virtual OverlayWindow *overlayWindow() {
+    OverlayWindow *overlayWindow() const override {
         return m_backend->overlayWindow();
     }
-    virtual bool usesOverlayWindow() const {
+    bool usesOverlayWindow() const override {
         return m_backend->usesOverlayWindow();
     }
-    Decoration::Renderer *createDecorationRenderer(Decoration::DecoratedClientImpl *client);
+    Decoration::Renderer *createDecorationRenderer(Decoration::DecoratedClientImpl *client) override;
 
     bool animationsSupported() const override {
         return true;
@@ -173,10 +173,10 @@ public:
 
     static SceneXrender *createScene(QObject *parent);
 protected:
-    virtual Scene::Window *createWindow(Toplevel *toplevel);
-    virtual void paintBackground(QRegion region);
-    virtual void paintGenericScreen(int mask, ScreenPaintData data);
-    virtual void paintDesktop(int desktop, int mask, const QRegion &region, ScreenPaintData &data);
+    Scene::Window *createWindow(Toplevel *toplevel) override;
+    void paintBackground(QRegion region) override;
+    void paintGenericScreen(int mask, ScreenPaintData data) override;
+    void paintDesktop(int desktop, int mask, const QRegion &region, ScreenPaintData &data) override;
     void paintCursor() override;
 private:
     explicit SceneXrender(XRenderBackend *backend, QObject *parent = nullptr);
@@ -190,13 +190,13 @@ class SceneXrender::Window
 {
 public:
     Window(Toplevel* c, SceneXrender *scene);
-    virtual ~Window();
-    virtual void performPaint(int mask, QRegion region, WindowPaintData data);
+    ~Window() override;
+    void performPaint(int mask, QRegion region, WindowPaintData data) override;
     QRegion transformedShape() const;
     void setTransformedShape(const QRegion& shape);
     static void cleanup();
 protected:
-    virtual WindowPixmap* createWindowPixmap();
+    WindowPixmap* createWindowPixmap() override;
 private:
     QRect mapToScreen(int mask, const WindowPaintData &data, const QRect &rect) const;
     QPoint mapToScreen(int mask, const WindowPaintData &data, const QPoint &point) const;
@@ -214,9 +214,9 @@ class XRenderWindowPixmap : public WindowPixmap
 {
 public:
     explicit XRenderWindowPixmap(Scene::Window *window, xcb_render_pictformat_t format);
-    virtual ~XRenderWindowPixmap();
+    ~XRenderWindowPixmap() override;
     xcb_render_picture_t picture() const;
-    virtual void create();
+    void create() override;
 private:
     xcb_render_picture_t m_picture;
     xcb_render_pictformat_t m_format;
@@ -227,15 +227,15 @@ class SceneXrender::EffectFrame
 {
 public:
     EffectFrame(EffectFrameImpl* frame);
-    virtual ~EffectFrame();
+    ~EffectFrame() override;
 
-    virtual void free();
-    virtual void freeIconFrame();
-    virtual void freeTextFrame();
-    virtual void freeSelection();
-    virtual void crossFadeIcon();
-    virtual void crossFadeText();
-    virtual void render(QRegion region, double opacity, double frameOpacity);
+    void free() override;
+    void freeIconFrame() override;
+    void freeTextFrame() override;
+    void freeSelection() override;
+    void crossFadeIcon() override;
+    void crossFadeText() override;
+    void render(QRegion region, double opacity, double frameOpacity) override;
     static void cleanup();
 
 private:
@@ -279,7 +279,7 @@ xcb_render_picture_t XRenderWindowPixmap::picture() const
  *
  * This class extends Shadow by the elements required for XRender rendering.
  * @author Jacopo De Simoi <wilderkde@gmail.org>
- **/
+ */
 class SceneXRenderShadow
     : public Shadow
 {
@@ -296,7 +296,7 @@ public:
     using Shadow::ShadowElementTopLeft;
     using Shadow::ShadowElementsCount;
     using Shadow::shadowPixmap;
-    virtual ~SceneXRenderShadow();
+    ~SceneXRenderShadow() override;
 
     void layoutShadowRects(QRect& top, QRect& topRight,
                            QRect& right, QRect& bottomRight,
@@ -305,8 +305,8 @@ public:
     xcb_render_picture_t picture(ShadowElements element) const;
 
 protected:
-    virtual void buildQuads();
-    virtual bool prepareBackend();
+    void buildQuads() override;
+    bool prepareBackend() override;
 private:
     XRenderPicture* m_pictures[ShadowElementsCount];
 };
@@ -323,7 +323,7 @@ public:
         Count
     };
     explicit SceneXRenderDecorationRenderer(Decoration::DecoratedClientImpl *client);
-    virtual ~SceneXRenderDecorationRenderer();
+    ~SceneXRenderDecorationRenderer() override;
 
     void render() override;
     void reparent(Deleted *deleted) override;
