@@ -142,11 +142,6 @@ bool ClientLevel::exclude(AbstractClient *client) const
             return true;
         }
     }
-    if (exclusions & ClientModel::NonSelectedWindowTabExclusion) {
-        if (!client->isCurrentTab()) {
-            return true;
-        }
-    }
     if (exclusions & ClientModel::NotAcceptingFocusExclusion) {
         if (!client->wantsInput()) {
             return true;
@@ -655,13 +650,6 @@ ClientModel::ClientModel(QObject *parent)
     , m_root(nullptr)
     , m_exclusions(NoExclusion)
 {
-    QHash<int, QByteArray> roleNames;
-    roleNames.insert(Qt::DisplayRole, "display");
-    roleNames.insert(ClientRole, "client");
-    roleNames.insert(ScreenRole, "screen");
-    roleNames.insert(DesktopRole, "desktop");
-    roleNames.insert(ActivityRole, "activity");
-    setRoleNames(roleNames);
 }
 
 ClientModel::~ClientModel()
@@ -711,7 +699,7 @@ QVariant ClientModel::data(const QModelIndex &index, int role) const
     }
     if (role == Qt::DisplayRole || role == ClientRole) {
         if (AbstractClient *client = m_root->clientForId(index.internalId())) {
-            return qVariantFromValue(client);
+            return QVariant::fromValue(client);
         }
     }
     return QVariant();
@@ -741,6 +729,17 @@ int ClientModel::rowCount(const QModelIndex &parent) const
     return 0;
 }
 
+QHash<int, QByteArray> ClientModel::roleNames() const
+{
+    return {
+        { Qt::DisplayRole, QByteArrayLiteral("display") },
+        { ClientRole, QByteArrayLiteral("client") },
+        { ScreenRole, QByteArrayLiteral("screen") },
+        { DesktopRole, QByteArrayLiteral("desktop") },
+        { ActivityRole, QByteArrayLiteral("activity") },
+    };
+}
+
 QModelIndex ClientModel::parent(const QModelIndex &child) const
 {
     if (!child.isValid() || child.column() != 0) {
